@@ -21,15 +21,19 @@ x <- c(sample.int(9, 2e5, replace = TRUE), sample(51:99, 8e5, replace = TRUE))
 ## ----plot-high-low, message=FALSE---------------------------------------------
 library(ggplot2)
 library(dplyr)
-tibble(x = x) %>% 
-  ggplot() + aes(x) + stat_density(bw = 3)
+tibble(x = x) %>%
+  ggplot() +
+  aes(x) +
+  stat_density(bw = 3)
 
 ## ----try-all------------------------------------------------------------------
 library(autothresholdr)
-thresh_methods <- c("IJDefault", "Huang", "Huang2", "Intermodes", "IsoData", 
-                    "Li", "Mean", "MinErrorI", "Minimum", "Moments", "Otsu",
-                    "Percentile", "RenyiEntropy", "Shanbhag", "Triangle")
-thresholds <- purrr::map_chr(thresh_methods, ~auto_thresh(x, .)) %>% 
+thresh_methods <- c(
+  "IJDefault", "Huang", "Huang2", "Intermodes", "IsoData",
+  "Li", "Mean", "MinErrorI", "Minimum", "Moments", "Otsu",
+  "Percentile", "RenyiEntropy", "Shanbhag", "Triangle"
+)
+thresholds <- purrr::map_chr(thresh_methods, ~ auto_thresh(x, .)) %>%
   tibble(method = thresh_methods, threshold = .)
 print(thresholds)
 
@@ -39,5 +43,5 @@ filter(thresholds, threshold >= 10, threshold <= 49)
 ## ----tri----------------------------------------------------------------------
 auto_thresh(x, "huang")
 auto_thresh(x, "tri")
-auto_thresh(x,  "otsu")
+auto_thresh(x, "otsu")
 
